@@ -64,7 +64,8 @@ else:
 SYNTAX_PATH = [ os.path.join('.', 'syntax'),
                 this_module_path,
                 os.path.join(os.path.expanduser('~'),".pygtkeditor"),
-                os.path.join(sys.prefix,"share","pygtkeditor","syntax")]         
+                os.path.join(sys.prefix,"share","pygtkeditor","syntax"),
+                '/opt/pygtkeditor/syntax']         
 
 # enable/disable debug-messages
 DEBUG_FLAG  = False
